@@ -15,12 +15,18 @@ from .__init__ import __version__
 from . import pack
 from . import web
 
+devmode = "--dev" in sys.argv
+
+cdn_dot = __version__.split(".")
+cdn_dot.pop()
+cdn_version = ".".join(cdn_dot)
+del cdn_dot
+
 
-# FIXME: remove later
-devmode = os.path.isfile("dev")
 if devmode:
+    sys.argv.remove("--dev")
     DEFAULT_PORT = 8666
-    DEFAULT_CDN = f"http://localhost:8000/"
+    DEFAULT_CDN = f"http://localhost:8000/archives/{cdn_version}/"
     DEFAULT_TMPL = "static/wip.tmpl"
     print(
         f"""
@@ -36,7 +42,7 @@ if devmode:
     )
 
 else:
-    DEFAULT_CDN = f"https://pygame-web.github.io/archives/{__version__}/"
+    DEFAULT_CDN = f"https://pygame-web.github.io/archives/{cdn_version}/"
     DEFAULT_PORT = 8000
     DEFAULT_TMPL = "default.tmpl"
 
@@ -104,18 +110,35 @@ async def main_run(patharg, cdn=DEFAULT_CDN):
         "--bind",
         default="localhost",
         metavar="ADDRESS",
-        help="Specify alternate bind address " "[default: localhost]",
+        help="Specify alternate bind address [default: localhost]",
     )
     parser.add_argument(
         "--directory",
         default=build_dir.as_posix(),
-        help="Specify alternative directory " "[default:%s]" % build_dir,
+        help="Specify alternative directory [default:%s]" % build_dir,
     )
 
+    parser.add_argument(
+        "--PYBUILD",
+        default="3.11",
+        help="Specify python version [default:%s]" % "3.11",
+    )
     parser.add_argument(
         "--app_name",
         default=app_folder.name,
-        help="Specify user facing name of application" "[default:%s]" % app_folder.name,
+        help="Specify user facing name of application [default:%s]" % app_folder.name,
+    )
+
+    parser.add_argument(
+        "--ume_block",
+        default=1,
+        help="Specify wait for user media engagement before running [default:%s]" % 1,
+    )
+
+    parser.add_argument(
+        "--can_close",
+        default=0,
+        help="Specify if window will ask confirmation for closing [default:%s]" % 0,
     )
 
     parser.add_argument(
@@ -131,13 +154,25 @@ async def main_run(patharg, cdn=DEFAULT_CDN):
     parser.add_argument("--title", default="", help="App nice looking name")
 
     parser.add_argument(
-        "--version", default=version, help="package name, please make it unique"
+        "--version",
+        default=__version__,
+        help="override prebuilt version path [default:%s]" % __version__,
     )
 
     parser.add_argument(
         "--build", action="store_true", help="build only, do not run test server"
     )
 
+    parser.add_argument(
+        "--html",
+        action="store_true",
+        help="build as html with embedded assets (pygame-script)",
+    )
+
+    parser.add_argument(
+        "--no_opt", action="store_true", help="turn off assets optimizer"
+    )
+
     parser.add_argument(
         "--archive", action="store_true", help="make build/web.zip archive for itch.io"
     )
@@ -149,7 +184,9 @@ async def main_run(patharg, cdn=DEFAULT_CDN):
     #    )
 
     parser.add_argument(
-        "--icon", default="favicon.png", help="package name, please make it unique"
+        "--icon",
+        default="favicon.png",
+        help="icon png file 32x32 min should be favicon.png",
     )
 
     parser.add_argument(
@@ -158,7 +195,11 @@ async def main_run(patharg, cdn=DEFAULT_CDN):
         help="web site to cache locally [default:%s]" % cdn,
     )
 
-    parser.add_argument("--template", default=DEFAULT_TMPL, help="index.html template")
+    parser.add_argument(
+        "--template",
+        default=DEFAULT_TMPL,
+        help="index.html template [default:%s]" % DEFAULT_TMPL,
+    )
 
     parser.add_argument(
         "--ssl", default=False, help="enable ssl with server.pem and key.pem"
@@ -217,6 +258,8 @@ now packing application ....
         "cdn": args.cdn,
         "proxy": f"http://{args.bind}:{args.port}/",
         "xtermjs": "1",
+        "ume_block": args.ume_block,
+        "can_close": args.can_close,
         "archive": app_name,
         "autorun": "0",
         "authors": "pgw",
@@ -225,6 +268,7 @@ now packing application ....
         "directory": app_name,
         "spdx": "cookiecutter.spdx",
         "version": __version__,
+        "PYBUILD": args.PYBUILD,
     }
 
     def cache_file(remote_url, suffix):
@@ -325,7 +369,7 @@ now packing application ....
                     if not line:
                         break
                     for k, v in CC.items():
-                        line = line.replace("{{cookiecutter." + k + "}}", v)
+                        line = line.replace("{{cookiecutter." + k + "}}", str(v))
 
                     target.write(line)
 
@@ -337,6 +381,7 @@ now packing application ....
     only building a web archive suitable for itch.io
     archive file will be :
         {build_dir}.zip
+
 """
             )
 
@@ -356,7 +401,7 @@ now packing application ....
 
 build_dir = {build_dir}
 
-            """
+"""
             )
     else:
         print(args.template, "is not a valid template")
